\name{FHtab}
\alias{FHtab}
\non_function{}
\title{Intergenerational mobility table}
\usage{data(FHtab)}
\description{
The \code{FHtab} data frame has 25 rows and 3 columns.
\code{OccFather} is father's occupation, \code{OccSon} is son's occupation, both have 5 categories (\emph{Upper nonmanual}, \emph{Lower nonmanual}, \emph{Upper manual}, \emph{Lower manual}, and \emph{Farm}. \code{Freq} contains the table frequencies
}
\source{
 Table from page 11 of \emph{Mobility Tables}. Original source:
 page 49 of \emph{Opportunity and Change}.
}
\references{
  Hout, Michael. (1983). \emph{Mobility Tables}. Sage Publication 07-03

  Featherman, David L., Robert M. Hauser. (1978).
  \emph{Opportunity and change}. New York: Academic Press.
}
\keyword{datasets}

\eof
\name{ctab}
\alias{ctab}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Percentage tables}
\description{
  Prints one-way, two-way or multiway percentage tables
}
\usage{
ctab(..., digits = 2, type = c("n", "row", "column", "total"),
row.vars = NULL, col.vars = NULL, percentages = TRUE)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{\dots}{one or more factors or a table object of class \code{table}, \code{xtabs}, or
  \code{ftable}}
  \item{digits}{number of decimal places (default 2)}
  \item{type}{Row, column, total percentages or counts (\code{type=n})}
  \item{row.vars}{}
  \item{col.vars}{Same as \code{\link{ftable}}}
  \item{percentages}{If \code{FALSE}, proportions rather than percentages are printed}
}
\details{
  Simplifies the production of (multiway) percentage tables.
}
\value{
  For one-way and two-way tables, a \code{table} object is returned. For three-way and higher tables,
  an \code{ftable} object is returned.
}
\references{\url{http://www.xs4all.nl/~jhckx/}}
\author{John Hendrickx <\email{John\_Hendrickx@yahoo.com}>}
\note{
If the table contains three or more factors, the first is treated by default as the row variable, the
second as the column variable, the third and following as grouping variables. This can be overridden
using \code{row.vars} and/or \code{col.vars}. Note that  \code{\link[pkg:gregmisc]{CrossTable}} in
the \code{gregmisc} package also provides an easy method for producing percentage tables but only for
two-way tables.
}

\seealso{\code{\link{table}}, \code{\link{ftable}}, \code{\link{xtabs}}, \code{\link{prop.table}},
\code{\link[pkg:gregmisc]{CrossTable}}
}

\examples{
data(Titanic)
ctab(Titanic)
ctab(Titanic,type="r")
ctab(Titanic,row.vars=1:3,type="r")
ctab(Titanic,col.vars=c(2,4),type="r")
ctab(Titanic,row.vars=c(1,3),type="c")
ctab(Titanic,col.vars=c("Sex","Survived"),type="r")
ctab(Titanic,col.vars=c("Sex","Survived"),type="t")
}
\keyword{category}

\eof
\name{logan}
\alias{logan}
\non_function{}
\title{Data from the 1972-78 GSS data used by Logan (1983: 332-333)}
\usage{data(logan)}
\description{
Intergenerational occupational mobility data with covariates.
}
\format{
  A data frame with 838 observations on the following 4 variables.
  \describe{
    \item{occ}{a factor with levels \code{farm}, \code{operatives}, \code{craftsmen}, \code{sales}, and \code{professional}}
    \item{focc}{a factor with levels \code{farm}, \code{operatives}, \code{craftsmen}, \code{sales}, and \code{professional}}
    \item{educ}{a numeric vector}
    \item{black}{a factor with levels \code{non-black} and \code{black}}
  }
}
\source{
 1972-78 GSS (cf. Logan, 1983: 332-333)
}
\references{
Logan, John A. (1983). A Multivariate Model for Mobility Tables. \emph{American Journal of
Sociology} 89: 324-349.}
\keyword{datasets}

\eof
\name{mclgen}

\alias{mclgen}
%- Also NEED an `\alias' for EACH other topic documented here.

\title{Restructure a data-frame as a "person-choice" file}

\description{
  \code{mclgen} restructures a data-frame into a \emph{person-choice}
  file for estimation of a multinomial logit as a conditional logit model
}

\usage{
mclgen(datamat, catvar)
}
%- maybe also `usage' for other objects documented here.

\arguments{
  \item{datamat}{A data-frame to be transformed into a
     \emph{person-choice} file}
  \item{catvar}{A factor representing the response variable
     (i.e. the dependent variable in a multinomial logistic model)}
}

\details{
  A multinomial logit model can be estimated using a program for conditional logit regression. This
  will produce the same coefficients and standard errors but allows greater flexibility for imposing
  restrictions on the dependent variable.

  To estimate the multinomial logistic model as a conditional logit model, the data must be
  restructured as a \emph{person-choice} file. \code{mclgen} performs this operation such that:

  \itemize{
    \item each record of the data-frame is duplicated \emph{ncat} times, where \emph{ncat} is the
    number of categories of the response variable
    \item A new variable \code{id} is created to index respondents. This variable is used as
    the stratifying variable in \code{clogit}
    \item A new variable \code{newy} is created to index response options for each respondent
    \item A new variable \code{depvar} is created which is equal to 1 for the record corresponding
    with the respondent's actual choice and is 0 otherwise
  }

  \code{depvar} is the dependent variable in \code{clogit}. The main effects of \code{catvar}
  correspond with the intercept term of a multinomial logit model, interactions of \code{catvar} with
  predictor variables correspond with the effects of these variables in a multinomial logit model.

  Since \code{catvar} is now on the right-hand side of the model equation, restrictions can be
  imposed in the usual fashion. For example, by using \code{\link[pkg:MASS]{contr.sdif}}
  in the MASS package for \code{catvar}, an adjacent logit model is obtained (Agresti 1990: 318).
  By adding the dummy variables for two categories of \code{catvar}, an equality constraint
  can be imposed on those categories. These equality constraints can then be imposed on the
  effects of some predictor variables but not others.

  Another use is to include a mobility model in a multinomial logistic regression model. Mobility
  models are loglinear models for square tables. They lie in the space between a model of
  independence and a saturated model. This is accomplished by imposing restrictions on the
  interaction effect of the row and column variable. A number of these special models have been
  developed, see Hout (1983) or Goodman (1984) for an overview.

  These loglinear mobility models can be seen as multinomial logistic regression models
  with special restrictions on the dependent variable. The nature of the restriction depends
  on the category of the predictor variable. In practise, mobility models can be included
  in an MCL model using the same specification as for a loglinear model. \R functions for
  several common mobility models can be found in \code{\link{sqtab}}.
}

\value{
  A data-frame is returned, restructured as a \emph{person-choice} file.
}

\references{
  Agresti, Alan. (1990). \emph{Categorical data analysis}. New York: John Wiley & Sons.

  Allison, Paul D. and Nicholas Christakis. (1994). Logit models for sets of ranked items. Pp.
  199-228 in \emph{Peter V. Marsden (ed.), Sociological Methodology}. Oxford: Basil Blackwell.

  Breen, Richard. (1994). Individual Level Models for Mobility Tables and Other Cross-
  Classifications. \emph{Sociological Methods & Research} 33: 147-173.

  Goodman, Leo A. (1984). \emph{The analysis of cross-classified data having ordered categories.}
  Cambridge, Mass.: Harvard University Press.

  Hendrickx, John. (2000). Special restrictions in multinomial logistic regression. \emph{Stata
  Technical Bulletin} 56: 18-26.

  Hendrickx, John, Ganzeboom, Harry B.G. (1998). Occupational Status Attainment in the Netherlands,
  1920-1990. A Multinomial Logistic Analysis. \emph{European Sociological Review} 14: 387-403.

  Hout, Michael. (1983). \emph{Mobility Tables}. Sage Publication 07-031.

  Logan, John A. (1983). A Multivariate Model for Mobility Tables. \emph{American Journal of
  Sociology 89}: 324-349.

  \url{http://www.xs4all.nl/~jhckx/}
}

\author{John Hendrickx \email{John\_Hendrickx@yahoo.com} }

\note{

  The effects of predictor variables are modelled as interactions with \code{depvar} but the main
  effects of the predictor variables are not included in the model since these are constant within
  strata. This causes problems due to the way \R handles contrasts in interaction effects. If lower
  order effects of variables are not included in a model then contrasts are not used in interactions
  with these variables (see \code{\link{terms.object}} under the heading \code{factors}). For
  example, in the model \code{~Y+Y:X1+Y:X2}, contrasts will only be used for the main effect of
  \code{Y}. For the interaction effects \code{Y:X1} and \code{Y:X2}, dummies for all levels of
  \code{Y} will be used. The dummies for \code{Y} are linearly dependent within strata of the
  conditional logit model, therefore a warning issues that \emph{"X matrix deemed to be singular"}
  and the dummy for the last level of \code{Y} is dropped. So the model is estimated but
  \code{depvar} is not coded as intended.

  The simplest workaround is to include the main effects of the predictor variables in the model,
  i.e. use \code{~Y*X1+Y*X2}. The main effects of \code{X1} and \code{X2} are constant within strata
  so a warning will issue that \emph{"X matrix deemed to be singular"} and these effects will be
  dropped from the model. This has no further consequences and \code{depvar} is coded as intended.

  A second workaround can be to use \code{\link{model.matrix}} to create the dummies for
  \code{depvar} using the intended contrast. See the example below.

  \code{\link[pkg:survival]{clogit}} does not accept weights. A workaround is to call
  \code{\link[pkg:survival]{coxph}} directly (see example below).

}

\seealso{\code{\link[pkg:survival]{clogit}},\code{\link[pkg:survival]{coxph}},
         \code{\link[pkg:nnet]{multinom}}, \code{\link{sqtab}}
}

\examples{
## Example 1
# data from the Data from the 1972-78 GSS used by Logan (1983)
data(logan)

# create the "person-choice" file
pc<-mclgen(logan,occ)
summary(pc)
attach(pc)

library(survival)
# The following specification will work but R won't drop
# cl.lr<-clogit(depvar~occ+occ:educ+occ:black+strata(id),data=pc)
# However, R won't drop the first category of "occ"
# in the interaction effects. The last category will be omitted
# instead due to linear dependence within strata.
# Fix for the problem, create dummies manually for "occ"
occ.X<-model.matrix(~pc$occ)
occ.X<-occ.X[,attributes(occ.X)$assign==1]
cl.lr<-clogit(depvar~occ.X+occ.X:educ+occ.X:black+strata(id),data=pc)
summary(cl.lr)

# Estimate a "quasi-uniform association" loglinear model for "focc" and "occ"
# with "educ" and "black" as covariates at the respondent level
cl.qu<-clogit(depvar~occ.X+occ.X:educ+occ.X:black+
  mob.qi(focc,occ)+mob.unif(focc,occ)+strata(id),data=pc)
summary(cl.qu)

data(housing,package="MASS")
housing.prsch<-mclgen(housing,Sat)
library(survival)
# clogit doesn't support the weights argument at present
# a work-around is to call coxph directly
# coxph warns that X is singular, because the main
# effects of Infl, Type, and Cont are dropped
coxph.prsch<-coxph(Surv(rep(1, NROW(housing.prsch)), depvar) ~
  Sat+Sat*Infl+Sat*Type+Sat*Cont+strata(id),
  weights = housing.prsch$Freq, data = housing.prsch)
summary(coxph.prsch)

# the same model using multinomial logistic regression
library(nnet)
house.mult<- multinom(Sat ~ Infl + Type + Cont, weights = Freq,
                      data = housing)
summary(house.mult,correlation=FALSE)

# compare the coefficients
m1<-coef(coxph.prsch)
m1<-m1[!is.na(m1)]
dim(m1)<-c(2,7)
m2<-coef(house.mult)
m1
m2
m1-m2
max(abs(m1-m2))
mean(abs(m1-m2))
}

\keyword{multivariate}

\eof
\name{sqtab}
\alias{sqtab}
\alias{check.square}
\alias{fitmacro}
\alias{mob.cp}
\alias{mob.eqmain}
\alias{mob.qi}
\alias{mob.rc1}
\alias{mob.symint}
\alias{mob.unif}
%- Also NEED an `\alias' for EACH other topic documented here.

\title{sqtab: models for square tables}

\description{
  These functions are used to estimate loglinear models for square tables such as quasi-independence,
  quasi-symmetry.
}

\usage{
mob.qi(rowvar, colvar, constrained = FALSE, print.labels = FALSE)
mob.eqmain(rowvar, colvar, print.labels = FALSE)
mob.symint(rowvar, colvar, print.labels = FALSE)
mob.cp(rowvar,colvar)
mob.unif(rowvar, colvar)
mob.rc1(rowvar, colvar, equal = FALSE, print.labels = FALSE)
fitmacro(object)
check.square(rowvar, colvar, equal = TRUE)
}

%- maybe also `usage' for other objects documented here.
\arguments{
  \item{rowvar}{Factor representing the row variable}
  \item{colvar}{Factor representing the column variable}
  \item{print.labels}{If FALSE (default) then numeric values rather than factor values are printed for compact results}
  \item{equal}{(\code{mob.rc1}) If TRUE, a homogeneous row and column effects model 1 with equal scale values for the row and column variables is estimated. Otherwise, a (regular) RC1 model is estimated with different scale values for the row and column variables
  \cr
  (\code{check.square}) If TRUE, the row and column variables must have the same number of categories}
  \item{constrained}{(\code{mob.qi})If TRUE, a quasi-independence model-constrained is estimated with a single parameter for the diagonal cells}
  \item{object}{(\code{fitmacro}) An object of class \code{glm} for \code{family=poisson} and \code{link=log}}
}
\details{
  These functions are used to estimate loglinear models for square tables:
  \item{mob.qi}{Quasi-independence}
  \item{mob.eqmain}{Equal main effects (Hope's halfway model)}
  \item{mob.symint}{Symmetric interaction}
  \item{mob.cp}{Crossings-parameter model}
  \item{mob.unif}{Uniform association}
  \item{mob.rc1}{Row and columns model 1}
  \item{fitmacro}{Calculates \code{BIC} and \code{AIC} relative to a saturated loglinear model}
  \item{check.square}{Internal function to check if row and column variables are both factors with the same number of levels}

}
\value{
  \item{mob.qi}{A factor that will produce coefficients for the diagonal cells of a table, using off-
  diagonal cells as base category}
  \item{mob.eqmain}{A design matrix with equality contraints on the main effects}
  \item{mob.symint}{A design matrix for an interaction with equality contraints on coefficients on
  opposite sides of the diagonal}
  \item{mob.cp}{A set of vectors for a crossings-parameter model}
  \item{mob.unif}{A vector for a uniform association model}
  \item{mob.rc1}{A set of vectors for a row and columns model 1}
  \item{fitmacro}{Prints deviance, df, BIC, AIC, number of parameters and N}
  \item{check.square}{Stops function if either the row or column variable is not a factor or if the
  number of levels is unequal}
}
\references{
  Hout, Michael. (1983). \emph{Mobility Tables}. Sage Publication 07-031.

  Goodman, Leo A. (1984). \emph{The analysis of cross-classified data having ordered categories.} Cambridge, Mass.: Harvard University Press.
}
\author{John Hendrickx <\email{John\_Hendrickx@yahoo.com}>}

\seealso{\code{\link{glm}}, \code{\link{mclgen}}}

\examples{
# Examples of loglinear models for square tables,
# from Hout, M. (1983). "Mobility Tables". Sage Publication 07-031

# Table from page 11 of "Mobility Tables"
# Original source: Featherman D.L., R.M. Hauser. (1978) "Opportunity and Change."
# New York: Academic, page 49

data(FHtab)
attach(FHtab)

xtabs(Freq ~ .,FHtab)

# independence model
indep<-glm(Freq~OccFather+OccSon,family=poisson())
summary(indep)
fitmacro(indep)

wt <- (OccFather != OccSon)
qi0<-glm(Freq~OccFather+OccSon,weights=wt,family=poisson())
# A quasi-independence loglinear model, using structural zeros
# (page 23 of "Mobility Tables").
#  0  1  1  1  1   values of variable "wt"
#  1  0  1  1  1
#  1  1  0  1  1
#  1  1  1  0  1
#  1  1  1  1  0
qi0<-glm(Freq~OccFather+OccSon,weights=wt,family=poisson())
summary(qi0)
fitmacro(qi0)

# Quasi-independence using a "dummy factor" to create the design
# vectors for the diagonal cells (page 23).
#  1  0  0  0  0
#  0  2  0  0  0
#  0  0  3  0  0
#  0  0  0  4  0
#  0  0  0  0  5
glm.qi<-glm(Freq~OccFather+OccSon+mob.qi(OccFather,OccSon),family=poisson())
summary(glm.qi)
fitmacro(glm.qi)

# Quasi-independence constrained (QPM-C, page 31)
# Single immobility parameter
#  1  0  0  0  0
#  0  1  0  0  0
#  0  0  1  0  0
#  0  0  0  1  0
#  0  0  0  0  1
glm.q0<-glm(Freq~OccFather+OccSon+mob.qi(OccFather,OccSon,constrained=TRUE),family=poisson())
# slightly different results than Hout also found in Stata: L2=2567.658, q0=0.964
summary(glm.q0)
fitmacro(glm.q0)

# Quasi-symmetry using the symmetric cross-classification (page 23)
#  0  1  2  3  4   values of variable "sym"
#  1  0  5  6  7
#  2  5  0  8  9
#  3  6  8  0 10
#  4  7  9 10  0  */
glm.qsym<-glm(Freq~OccFather+OccSon+mob.symint(OccFather,OccSon),family=poisson())
summary(glm.qsym)
fitmacro(glm.qsym)

symmetry<-glm(Freq~mob.eqmain(OccFather,OccSon)+mob.symint(OccFather,OccSon),family=poisson())
summary(symmetry)
fitmacro(symmetry)

# Crossings parameter model (page 35)
#  0  v1 v1 v1 v1 |  0  0  v2 v2 v2 |  0  0  0  v3 v3 |  0  0  0  0  v4
#  v1 0  0  0  0  |  0  0  v2 v2 v2 |  0  0  0  v3 v3 |  0  0  0  0  v4
#  v1 0  0  0  0  |  v2 v2 0  0  0  |  0  0  0  v3 v3 |  0  0  0  0  v4
#  v1 0  0  0  0  |  v2 v2 0  0  0  |  v3 v3 v3 0  0  |  0  0  0  0  v4
#  v1 0  0  0  0  |  v2 v2 0  0  0  |  v3 v3 v3 0  0  |  v4 v4 v4 v4 0
glm.cp<-glm(Freq~OccFather+OccSon+mob.cp(OccFather,OccSon),family=poisson())
summary(glm.cp)
fitmacro(glm.cp)

# Uniform association model: linear by linear association (page 58)
glm.unif<-glm(Freq~OccFather+OccSon+mob.unif(OccFather,OccSon),family=poisson())
summary(glm.unif)
fitmacro(glm.unif)

# RC model 1 (unequal row and column effects, page 58)
# Fits a uniform association parameter and row and column effect
# parameters. Row and column effect parameters have the
# restriction that the first and last categories are zero.
glm.rc1<-glm(Freq~OccFather+OccSon+mob.rc1(OccFather,OccSon),family=poisson())
summary(glm.rc1)
fitmacro(glm.rc1)

# Homogeneous row and column effects model 1 (page 58)
# An equality restriction is placed on the row and column effects
glm.hrc1<-glm(Freq~OccFather+OccSon+mob.rc1(OccFather,OccSon,equal=TRUE),family=poisson())
# Results differ from those in Hout, replicated by other programs
summary(glm.hrc1)
fitmacro(glm.hrc1)
}

\keyword{multivariate}

\eof
